Function rrise::communication::term
source · [−]pub fn term()Expand description
Terminates the communication module.
Warning This function must be called before the memory manager is terminated.
pub fn term()Terminates the communication module.
Warning This function must be called before the memory manager is terminated.