Function rrise::game_syncs::set_state
source · [−]Expand description
Sets the state of a State Group.
Return
- AkResult::AK_Success if successful
- AkResult::AK_IDNotFound if the state or State Group name was not resolved to an existing ID. Make sure that the banks were generated with the “include string” option.
Panics if state_group and state_id are not of the same variant.