pub struct SetRtpcValue<'a> { /* private fields */ }
Helper to set or reset RTPCs.

Use SetRtpcValue::set or SetRtpcValue::reset to post the change to Wwise.

Implementations

Value to set.

Note Doesn’t consume self so that it’s easier to reuse the same SetRTPCValue struct with different values over time.

Associated game object ID.

With this function, you may set a game parameter value with global scope (default) or with game object scope. Game object scope superseeds global scope. (Once a value is set for the game object scope, it will not be affected by changes to the global scope value.) Game parameter values set with global scope are applied to all game objects that not yet registered, or already registered but not overridden with a value with game object scope. To set a game parameter value with global scope, leave the default or pass AK_INVALID_GAME_OBJECT as the game object.

Default: AK_INVALID_GAME_OBJECT

Associated playing ID.

With this function, you may set a game parameter value on playing ID scope. Playing id scope superseeds both game object scope and global scope. Ignores any target game object set with for_target.

Default: AK_INVALID_PLAYING_ID

Duration during which the game parameter is interpolated towards in_value.

With this function, you may change the value of a game parameter over time. To do so, specify a non-zero value for ms. At each audio frame, the game parameter value will be updated internally according to the interpolation curve (set with with_interp_curve). If you call set with ms = 0 in the middle of an interpolation, the interpolation stops and the new value is set directly. Thus, if you call set at every game frame, you should not use with_interp_millis, as it would have no effect and it is less efficient.

Default: 0

When with_interp_millis is used and non-zero, describes the Curve type to be used for the game parameter interpolation.

Default: AkCurveInterpolation::AkCurveInterpolation_Linear

True if you want to bypass the internal “slew rate” or “over time filtering” specified by the sound designer. This is meant to be used when for example loading a level and you dont want the values to interpolate.

Default: false

Post this RTPC configuration to Wwise.

Post a reset of this RTPC configuration to Wwise.

Resets the value of the game parameter to its default value, as specified in the Wwise project.

Incompatible with for_playing_id; only works at global or game object scope, set with for_target.