Function rrise::memory_mgr::term
source · [−]pub fn term()Expand description
Terminate the Memory Manager.
Warning This function is not thread-safe. It is not valid to allocate memory or otherwise interact with the memory manager during or after this call.