Function rrise::music_engine::term
source · [−]pub fn term()Expand description
Terminate the music engine.
Warning This function must be called before calling Term() on the base sound engine.
pub fn term()Terminate the music engine.
Warning This function must be called before calling Term() on the base sound engine.