pub enum RtpcValueType {
    Default(AkRtpcValue),
    Global(AkRtpcValue),
    GameObject(AkRtpcValue),
    PlayingID(AkRtpcValue),
    Unavailable(),
}
Enum used to request a specific RTPC Value.

Also used to inform the user of where the RTPC Value comes from.

For example, the user may request the GameObject specific value by specifying RTPCValue_GameObject and can receive the Global Value if there was no GameObject specific value, and even the default value is there was no Global value either.

See also get_rtpc_value

Variants

Default(AkRtpcValue)

The value is the Default RTPC.

Global(AkRtpcValue)

The value is the Global RTPC.

GameObject(AkRtpcValue)

The value is the game object specific RTPC.

PlayingID(AkRtpcValue)

The value is the playing ID specific RTPC.

Unavailable()

The value is not available for the RTPC specified.