#[repr(C)]
pub struct AkCommSettings { pub ports: AkCommSettings_Ports, pub commSystem: c_int, pub bInitSystemLib: bool, pub szAppNetworkName: [c_char; 64], }
Platform-independent initialization settings of communication module between the Wwise sound engine and authoring tool. \sa

  • AK::Comm::Init()

Fields

ports: AkCommSettings_Ports

Ports used for communication between the Wwise authoring application and your game. \sa

  • \ref initialization_comm
  • AkCommSettings::Ports
  • AK::Comm::Init()
commSystem: c_int

Select the device of the communication system. By default, connecting to the Authoring tool \sa

  • \ref initialization_comm
  • AkCommSettings::AkCommSystem
  • AK::Comm::Init()
bInitSystemLib: bool

Tells if the base console communication library should be initialized. If set to false, the game should load/initialize the console’s communication library prior to calling this function. Set to false only if your game already use sockets before the sound engine initialization. Some consoles have critical requirements for initialization, see \ref initialization_comm_console_lib

szAppNetworkName: [c_char; 64]

Optional name that will be displayed over network remote connection of Wwise. It must be a NULL terminated string.