Struct rrise::settings::AkInitSettings
source · [−]pub struct AkInitSettings { /* private fields */ }Expand description
Platform-independent initialization settings of the sound engine See also
Implementations
sourceimpl AkInitSettings
impl AkInitSettings
sourcepub fn with_plugin_dll_path<T: AsRef<str>>(self, path: T) -> Self
pub fn with_plugin_dll_path<T: AsRef<str>>(self, path: T) -> Self
When using DLLs for plugins, specify their path. Leave NULL if DLLs are in the same folder as the game executable.
Note that on Windows, if path has spaces, the DLLs won’t be discovered properly.