Function rrise::sound_engine::stop_all
source · [−]pub fn stop_all(game_object_id: Option<AkGameObjectID>)Expand description
Stops the current content playing associated to the specified game object ID.
If no game object is specified, all sounds will be stopped.