pub fn term()
Terminates the sound engine.

If some sounds are still playing or events are still being processed when this function is called, they will be stopped.

Warning This function is not thread-safe.

Warning Before calling Term, you must ensure that no other thread is accessing the sound engine.

See also