pub fn unregister_all_game_obj() -> Result<(), AkResult>
Unregister all game objects, or all game objects with a particular matching set of property flags.

This function to can be used to unregister all game objects.

Return AK_Success if successful

Remark Registering a game object twice does nothing. Unregistering it once unregisters it no matter how many times it has been registered. Unregistering a game object while it is in use is allowed, but the control over the parameters of this game object is lost. For example, if a sound associated with this game object is a 3D moving sound, it will stop moving once the game object is unregistered, and there will be no way to recover the control over this game object.

See also