#[repr(C)]
pub struct AkSegmentInfo { pub iCurrentPosition: AkTimeMs, pub iPreEntryDuration: AkTimeMs, pub iActiveDuration: AkTimeMs, pub iPostExitDuration: AkTimeMs, pub iRemainingLookAheadTime: AkTimeMs, pub fBeatDuration: AkReal32, pub fBarDuration: AkReal32, pub fGridDuration: AkReal32, pub fGridOffset: AkReal32, }
Structure used to query info on active playing segments.

Fields

iCurrentPosition: AkTimeMs

Current position of the segment, relative to the Entry Cue, in milliseconds. Range is [-iPreEntryDuration, iActiveDuration+iPostExitDuration].

iPreEntryDuration: AkTimeMs

Duration of the pre-entry region of the segment, in milliseconds.

iActiveDuration: AkTimeMs

Duration of the active region of the segment (between the Entry and Exit Cues), in milliseconds.

iPostExitDuration: AkTimeMs

Duration of the post-exit region of the segment, in milliseconds.

iRemainingLookAheadTime: AkTimeMs

Number of milliseconds remaining in the “looking-ahead” state of the segment, when it is silent but streamed tracks are being prefetched.

fBeatDuration: AkReal32

Beat Duration in seconds.

fBarDuration: AkReal32

Bar Duration in seconds.

fGridDuration: AkReal32

Grid duration in seconds.

fGridOffset: AkReal32

Grid offset in seconds.