pub fn is_initialized() -> bool
Query whether the Memory Manager has been successfully initialized.

Warning This function is not thread-safe. It should not be called at the same time as MemoryMgr::Init or MemoryMgr::Term.

Return True if the Memory Manager is initialized, False otherwise

See also