pub fn init(
    init_settings: AkInitSettings,
    platform_init_settings: AkPlatformInitSettings
) -> Result<(), AkResult>
Initialize the sound engine.

Warning This function is not thread-safe.

Remark The initial settings should be initialized using AkInitSettings::default and AkPlatformInitSettings::default to fill the structures with their default settings. This is not mandatory, but it helps avoid backward compatibility problems.

Return

See also