pub fn is_initialized() -> bool
Query whether or not the sound engine has been successfully initialized.
Warning This function is not thread-safe. It should not be called at the same time as init() or term().
Return True if the sound engine has been initialized, False otherwise.
True
False
See also
init term