Function rrise::stream_mgr::init
source · [−]pub fn init(settings: AkStreamMgrSettings) -> Result<(), AkResult>Expand description
Stream Manager factory.
Remarks
- In order for the Stream Manager to work properly, you also need to create at least one streaming device (and implement its I/O hook), and register the File Location Resolver with AK::StreamMgr::SetFileLocationResolver().
- Use AkStreamMgrSettings::default, then modify the settings you want, then feed this function with them.
See also