Function rrise::stream_mgr::init_default_stream_mgr
source · [−]pub fn init_default_stream_mgr<T: AsRef<str>>(
stream_mgr_settings: AkStreamMgrSettings,
device_settings: AkDeviceSettings,
bank_location: T
) -> Result<(), AkResult>Expand description
Initializes the default streaming manager, specifying the folder in which to find the generated soundbanks when they are loaded.