Struct rrise::AkSegmentInfo
source · [−]#[repr(C)]pub struct AkSegmentInfo {
pub iCurrentPosition: AkTimeMs,
pub iPreEntryDuration: AkTimeMs,
pub iActiveDuration: AkTimeMs,
pub iPostExitDuration: AkTimeMs,
pub iRemainingLookAheadTime: AkTimeMs,
pub fBeatDuration: AkReal32,
pub fBarDuration: AkReal32,
pub fGridDuration: AkReal32,
pub fGridOffset: AkReal32,
}Expand description
Structure used to query info on active playing segments.
Fields
iCurrentPosition: AkTimeMsCurrent position of the segment, relative to the Entry Cue, in milliseconds. Range is [-iPreEntryDuration, iActiveDuration+iPostExitDuration].
iPreEntryDuration: AkTimeMsDuration of the pre-entry region of the segment, in milliseconds.
iActiveDuration: AkTimeMsDuration of the active region of the segment (between the Entry and Exit Cues), in milliseconds.
iPostExitDuration: AkTimeMsDuration of the post-exit region of the segment, in milliseconds.
iRemainingLookAheadTime: AkTimeMsNumber of milliseconds remaining in the “looking-ahead” state of the segment, when it is silent but streamed tracks are being prefetched.
fBeatDuration: AkReal32Beat Duration in seconds.
fBarDuration: AkReal32Bar Duration in seconds.
fGridDuration: AkReal32Grid duration in seconds.
fGridOffset: AkReal32Grid offset in seconds.